summaryrefslogtreecommitdiff
path: root/engine/items/tmhm.asm
diff options
context:
space:
mode:
Diffstat (limited to 'engine/items/tmhm.asm')
-rwxr-xr-xengine/items/tmhm.asm6
1 files changed, 3 insertions, 3 deletions
diff --git a/engine/items/tmhm.asm b/engine/items/tmhm.asm
index 5b7b4e8e..01a48ebb 100755
--- a/engine/items/tmhm.asm
+++ b/engine/items/tmhm.asm
@@ -1,10 +1,10 @@
; checks if the mon in wWhichPokemon already knows the move in $d0e0
CheckIfMoveIsKnown: ; 2fe18 (b:7e18)
ld a, [wWhichPokemon]
- ld hl, W_PARTYMON1_MOVE1
+ ld hl, wPartyMon1Moves
ld bc, $2c
call AddNTimes
- ld a, [$d0e0]
+ ld a, [wd0e0]
ld b, a
ld c, $4 ; nubmer of moves
.loop
@@ -1,10 +1,10 @@
-; checks if the mon in wWhichPokemon already knows the move in $d0e0
+; checks if the mon in wWhichPokemon already knows the move in wd0e0
CheckIfMoveIsKnown: ; 2fe18 (b:7e18)
ld a, [wWhichPokemon]